# Broke: Smooth broken link checker for git repositories

If it ain't broke, don't fix it. Install with

`pip install broke`

From the base of any git repo simply type

`broke`

to see all broken links referenced in all files of a directory tracked by `git`, excluding the
files in your `.gitignore`.
